==> download.php?FileName=terralib-5.3.2.zip: share/terralib/translations/terralib_mod_qt_plugins_rp_pt_br.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>QObject</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/RasterConfigWidgetFactory.cpp" line="53"/>
        <source>Raster processing</source>
        <translation>Processamento de Imagens</translation>
    </message>
</context>
<context>
    <name>RasterConfigWidgetForm</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ui/RasterConfigWidgetForm.ui" line="14"/>
        <source>General Configurations</source>
        <translation>Configurações Gerais</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ui/RasterConfigWidgetForm.ui" line="22"/>
        <source>Multi Resolution</source>
        <translation>Multirresolução</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ui/RasterConfigWidgetForm.ui" line="34"/>
        <source>Interpolator:</source>
        <translation>Interpolador:</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ui/RasterConfigWidgetForm.ui" line="41"/>
        <source>Levels:</source>
        <translation>Níveis:</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ui/RasterConfigWidgetForm.ui" line="88"/>
        <source>Question to add multi resolution on output layer</source>
        <translation>Pergunta para adicionar a multirresolução na camada de saída</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ui/RasterConfigWidgetForm.ui" line="110"/>
        <source>Add multi resolutin on layer by default</source>
        <translation>Adiciona a multirresolução nas camadas por padrão</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::ArithmeticOpAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ArithmeticOpAction.cpp" line="39"/>
        <source>Arithmetic Operations...</source>
        <translation>Operações Aritméticas ...</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::ClassifierAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ClassifierAction.cpp" line="42"/>
        <source>Classifier...</source>
        <translation>Classificador...</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::ClippingAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ClippingAction.cpp" line="43"/>
        <location filename="../../../src/terralib/qt/plugins/rp/ClippingAction.cpp" line="46"/>
        <source>Clipping...</source>
        <translation>Recorte...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ClippingAction.cpp" line="114"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ClippingAction.cpp" line="114"/>
        <source>The layer selected is invalid or does not have an raster representation.</source>
        <translation>A camada selecionada é inválida ou não tem uma representação matricial (raster).</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::CloudDetectionAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/CloudDetectionAction.cpp" line="43"/>
        <source>Cloud Detection...</source>
        <translation>Detecção de Nuvens...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/CloudDetectionAction.cpp" line="57"/>
        <location filename="../../../src/terralib/qt/plugins/rp/CloudDetectionAction.cpp" line="63"/>
        <source>Cloud Detection</source>
        <translation>Detecção de Nuvens</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/CloudDetectionAction.cpp" line="57"/>
        <source>There is no selected raster layer.</source>
        <translation>Não há uma camada imagem selecionada.</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/CloudDetectionAction.cpp" line="63"/>
        <source>The layer is not checked.</source>
        <translation>A camada não foi marcada.</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::ColorTransformAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ColorTransformAction.cpp" line="41"/>
        <source>Color Transform...</source>
        <translation>Transformação de Cores...</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::ComposeBandsAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ComposeBandsAction.cpp" line="40"/>
        <source>Compose / Decompose Bands...</source>
        <translation>Compõe / Decompõe Bandas...</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::ContrastAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ContrastAction.cpp" line="45"/>
        <source>Contrast...</source>
        <translation>Contraste...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ContrastAction.cpp" line="60"/>
        <location filename="../../../src/terralib/qt/plugins/rp/ContrastAction.cpp" line="69"/>
        <location filename="../../../src/terralib/qt/plugins/rp/ContrastAction.cpp" line="79"/>
        <location filename="../../../src/terralib/qt/plugins/rp/ContrastAction.cpp" line="121"/>
        <location filename="../../../src/terralib/qt/plugins/rp/ContrastAction.cpp" line="141"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ContrastAction.cpp" line="69"/>
        <location filename="../../../src/terralib/qt/plugins/rp/ContrastAction.cpp" line="141"/>
        <source>The layer is not checked!</source>
        <translation>A camada não está marcada!</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ContrastAction.cpp" line="60"/>
        <source>There is no selected raster layer.</source>
        <translation>Não há uma camada imagem selecionada.</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ContrastAction.cpp" line="79"/>
        <source>Layers with raster palette are not able to apply contrast!</source>
        <translation>Camadas com imagens com palheta não podem ser contrastadas!</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ContrastAction.cpp" line="121"/>
        <source>The layer selected is invalid or does not have an raster representation.</source>
        <translation>A camada selecionada é inválida ou não tem uma representação matricial (raster).</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::FilterAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/FilterAction.cpp" line="41"/>
        <source>Filter...</source>
        <translation>Filtragem...</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::FusionAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/FusionAction.cpp" line="40"/>
        <source>Fusion...</source>
        <translation>Fusão...</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::MixtureModelAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/MixtureModelAction.cpp" line="42"/>
        <source>Mixture Model...</source>
        <translation>Modelo de Mistura...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/MixtureModelAction.cpp" line="109"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/MixtureModelAction.cpp" line="109"/>
        <source>The layer selected is invalid or does not have an raster representation.</source>
        <translation>A camada selecionada é inválida ou não tem uma representação matricial (raster).</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::MosaicAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/MosaicAction.cpp" line="40"/>
        <source>Mosaic...</source>
        <translation>Mosaico...</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::PCAAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/PCAAction.cpp" line="43"/>
        <location filename="../../../src/terralib/qt/plugins/rp/PCAAction.cpp" line="46"/>
        <source>PCA...</source>
        <translation>PCA...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/PCAAction.cpp" line="109"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/PCAAction.cpp" line="109"/>
        <source>The layer selected is invalid or does not have an raster representation.</source>
        <translation>A camada selecionada é inválida ou não tem uma representação matricial (raster).</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::PostClassificationAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/PostClassificationAction.cpp" line="39"/>
        <source>Post Classification...</source>
        <translation>Pós Calssificação...</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::RasterConfigWidget</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/RasterConfigWidget.cpp" line="42"/>
        <source>Changes the raster processing configurations of the application.</source>
        <translation>
Altera as configurações de processamento de imagens do aplicativo.</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/RasterConfigWidget.cpp" line="111"/>
        <source>Nearest Neighbor</source>
        <translation>Vizinho mais próximo</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/RasterConfigWidget.cpp" line="112"/>
        <source>Bilinear</source>
        <translation>Bilinear</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/RasterConfigWidget.cpp" line="113"/>
        <source>Bicubic</source>
        <translation>Bicúbico</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::RasterSlicingAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/RasterSlicingAction.cpp" line="44"/>
        <source>Raster Slicing...</source>
        <translation>Fatiamento de imagem...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/RasterSlicingAction.cpp" line="113"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/RasterSlicingAction.cpp" line="113"/>
        <source>The layer selected is invalid or does not have an raster representation.</source>
        <translation>A camada selecionada é inválida ou não tem uma representação matricial (raster).</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::RasterizationAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/RasterizationAction.cpp" line="31"/>
        <source>Rasterization...</source>
        <translation>Rasterização...</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::RegisterAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/RegisterAction.cpp" line="39"/>
        <source>Register...</source>
        <translation>Registro...</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::SegmenterAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/SegmenterAction.cpp" line="41"/>
        <source>Segmenter...</source>
        <translation>Segmentação...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/SegmenterAction.cpp" line="87"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/SegmenterAction.cpp" line="87"/>
        <source>The layer selected is invalid or does not have an raster representation.</source>
        <translation>A camada selecionada é inválida ou não tem uma representação matricial (raster).</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::VectorizationAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/VectorizationAction.cpp" line="29"/>
        <source>Vectorization...</source>
        <translation>Vetorização...</translation>
    </message>
</context>
</TS>

==> download.php?FileName=terralib-5.4.0.zip: share/terralib/translations/terralib_mod_qt_plugins_rp_pt_br.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>QObject</name>
    <message>
        <source>Raster Processing</source>
        <translation type="vanished">Processamento Matricial</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/RasterConfigWidgetFactory.cpp" line="52"/>
        <source>Raster processing</source>
        <translation>Processamento Matricial</translation>
    </message>
</context>
<context>
    <name>RasterConfigWidgetForm</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ui/RasterConfigWidgetForm.ui" line="14"/>
        <source>General Configurations</source>
        <translation>Configurações Gerais</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ui/RasterConfigWidgetForm.ui" line="22"/>
        <source>Multi Resolution</source>
        <translation>Multirresolução</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ui/RasterConfigWidgetForm.ui" line="34"/>
        <source>Interpolator:</source>
        <translation>Interpolador:</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ui/RasterConfigWidgetForm.ui" line="41"/>
        <source>Levels:</source>
        <translation>Níveis:</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ui/RasterConfigWidgetForm.ui" line="88"/>
        <source>Question to add multi resolution on output layer</source>
        <translation>Pergunta para adicionar a multirresolução na camada de saída</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ui/RasterConfigWidgetForm.ui" line="110"/>
        <source>Add multi resolutin on layer by default</source>
        <translation>Adiciona a multirresolução nas camadas por padrão</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::ArithmeticOpAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ArithmeticOpAction.cpp" line="39"/>
        <source>Arithmetic Operations...</source>
        <translation>Operações Aritméticas ...</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::BoundaryExtractionAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/BoundaryExtractionAction.cpp" line="29"/>
        <source>Boundary Extraction...</source>
        <translation>Extração de Limites...</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::ClassifierAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ClassifierAction.cpp" line="42"/>
        <source>Classifier...</source>
        <translation>Classificador...</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::ClippingAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ClippingAction.cpp" line="43"/>
        <location filename="../../../src/terralib/qt/plugins/rp/ClippingAction.cpp" line="46"/>
        <source>Clipping...</source>
        <translation>Recorte...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ClippingAction.cpp" line="113"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ClippingAction.cpp" line="113"/>
        <source>The layer selected is invalid or does not have an raster representation.</source>
        <translation>A camada selecionada é inválida ou não tem uma representação matricial (raster).</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::CloudDetectionAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/CloudDetectionAction.cpp" line="43"/>
        <source>Cloud Detection...</source>
        <translation>Detecção de Nuvens...</translation>
    </message>
    <message>
        <source>Cloud Detection</source>
        <translation type="vanished">Detecção de Nuvens</translation>
    </message>
    <message>
        <source>There is no selected raster layer.</source>
        <translation type="vanished">Não há uma camada imagem selecionada.</translation>
    </message>
    <message>
        <source>The layer is not checked.</source>
        <translation type="vanished">A camada não foi marcada.</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::ColorTransformAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ColorTransformAction.cpp" line="41"/>
        <source>Color Transform...</source>
        <translation>Transformação de Cores...</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::ComposeBandsAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ComposeBandsAction.cpp" line="40"/>
        <source>Compose / Decompose Bands...</source>
        <translation>Compõe / Decompõe Bandas...</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::ContrastAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ContrastAction.cpp" line="45"/>
        <source>Contrast...</source>
        <translation>Contraste...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ContrastAction.cpp" line="58"/>
        <source>Contrast</source>
        <translation>Contraste</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ContrastAction.cpp" line="99"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ContrastAction.cpp" line="99"/>
        <source>The layer is not checked!</source>
        <translation>A camada não está marcada!</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/ContrastAction.cpp" line="58"/>
        <source>There is no selected raster layer.</source>
        <translation>Não há uma camada imagem selecionada.</translation>
    </message>
    <message>
        <source>Layers without Band information!</source>
        <translation type="vanished">Camada sem informação de Banda!</translation>
    </message>
    <message>
        <source>Layers with raster palette are not able to apply contrast!</source>
        <translation type="vanished">Camadas com imagens com palheta não podem ser contrastadas!</translation>
    </message>
    <message>
        <source>The layer selected is invalid or does not have an raster representation.</source>
        <translation type="vanished">A camada selecionada é inválida ou não tem uma representação matricial (raster).</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::FilterAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/FilterAction.cpp" line="41"/>
        <source>Filter...</source>
        <translation>Filtragem...</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::FusionAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/FusionAction.cpp" line="40"/>
        <source>Fusion...</source>
        <translation>Fusão...</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::MixtureModelAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/MixtureModelAction.cpp" line="42"/>
        <source>Mixture Model...</source>
        <translation>Modelo de Mistura...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/MixtureModelAction.cpp" line="109"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/MixtureModelAction.cpp" line="109"/>
        <source>The layer selected is invalid or does not have an raster representation.</source>
        <translation>A camada selecionada é inválida ou não tem uma representação matricial (raster).</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::MosaicAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/MosaicAction.cpp" line="40"/>
        <source>Mosaic...</source>
        <translation>Mosaico...</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::PCAAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/PCAAction.cpp" line="43"/>
        <location filename="../../../src/terralib/qt/plugins/rp/PCAAction.cpp" line="46"/>
        <source>PCA...</source>
        <translation>PCA...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/PCAAction.cpp" line="107"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/PCAAction.cpp" line="107"/>
        <source>The layer selected is invalid or does not have an raster representation.</source>
        <translation>A camada selecionada é inválida ou não tem uma representação matricial (raster).</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::PaletteAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/PaletteAction.cpp" line="40"/>
        <source>Converts to palette raster...</source>
        <translation>Converte para raster com paleta...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/PaletteAction.cpp" line="55"/>
        <source>There is no selected  layer.</source>
        <translation>Não há uma camada selecionada.</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/PaletteAction.cpp" line="60"/>
        <source>Layer</source>
        <translation>Camada</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/PaletteAction.cpp" line="72"/>
        <location filename="../../../src/terralib/qt/plugins/rp/PaletteAction.cpp" line="79"/>
        <source>Palette Raster</source>
        <translation>Imagem com Paleta</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/PaletteAction.cpp" line="72"/>
        <source>The operation was concluded successfully. Would you like to add the layer to the project?</source>
        <translation>A operação foi concluída com sucesso. Deseja acrescentar a camada ao projeto?</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::Plugin</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/Plugin.cpp" line="150"/>
        <location filename="../../../src/terralib/qt/plugins/rp/Plugin.cpp" line="154"/>
        <source>Raster Processing</source>
        <translation>Processamento Matricial</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::PostClassificationAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/PostClassificationAction.cpp" line="39"/>
        <source>Post Classification...</source>
        <translation>Pós Calssificação...</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::RasterConfigWidget</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/RasterConfigWidget.cpp" line="42"/>
        <source>Changes the raster processing configurations of the application.</source>
        <translation>Altera as configurações de processamento matricial do aplicativo.</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/RasterConfigWidget.cpp" line="109"/>
        <source>Nearest Neighbor</source>
        <translation>Vizinho mais próximo</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/RasterConfigWidget.cpp" line="110"/>
        <source>Bilinear</source>
        <translation>Bilinear</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/RasterConfigWidget.cpp" line="111"/>
        <source>Bicubic</source>
        <translation>Bicúbico</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::RasterSlicingAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/RasterSlicingAction.cpp" line="44"/>
        <source>Raster Slicing...</source>
        <translation>Fatiamento de imagem...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/RasterSlicingAction.cpp" line="113"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/RasterSlicingAction.cpp" line="113"/>
        <source>The layer selected is invalid or does not have an raster representation.</source>
        <translation>A camada selecionada é inválida ou não tem uma representação matricial (raster).</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::RasterizationAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/RasterizationAction.cpp" line="31"/>
        <source>Rasterization...</source>
        <translation>Rasterização...</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::RegisterAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/RegisterAction.cpp" line="39"/>
        <source>Register...</source>
        <translation>Registro...</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::SegmenterAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/SegmenterAction.cpp" line="41"/>
        <source>Segmenter...</source>
        <translation>Segmentação...</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/SegmenterAction.cpp" line="87"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/SegmenterAction.cpp" line="87"/>
        <source>The layer selected is invalid or does not have an raster representation.</source>
        <translation>A camada selecionada é inválida ou não tem uma representação matricial (raster).</translation>
    </message>
</context>
<context>
    <name>te::qt::plugins::rp::VectorizationAction</name>
    <message>
        <location filename="../../../src/terralib/qt/plugins/rp/VectorizationAction.cpp" line="29"/>
        <source>Vectorization...</source>
        <translation>Vetorização...</translation>
    </message>
</context>
</TS>
